@@ -28,6 +28,7 @@ from __future__ import print_function
 
 # Import built-in modules
 import os
+import re
 import sys
 
 # Import local modules
@@ -156,11 +157,12 @@ class ProxyClass(ProxyBase):
             return
 
         is_layout = issubclass(self.__class__, QtWidgets.QLayout)
+        is_action = issubclass(self.__class__, QtWidgets.QAction)
         is_window = issubclass(self.__class__, QtWidgets.QMainWindow)
         has_dot = str(self.__class__).count(".")
         is_one = len(args) == 1
 
-        condition = is_layout and has_dot or not is_one
+        condition = is_action or is_layout or has_dot or not is_one
         call_args = ", ".join(map(str, args)) if condition else f"parent={args[0]}"
         call_args = "" if is_window else call_args
         widget_name = moduleMember(self.module, self.__class__.__name__)
@@ -247,8 +249,12 @@ class QtCore(ProxyNamespace):
             if slot_name.endswith(".raise"):
                 args = list(args[:-1])
                 args.append(Literal(slot_name + "_"))
-
-            ProxyClassMember(cls, "connect", 0)(*args)
+            sender = args[0]
+            signal = args[1]
+            slot = args[2]
+            match = re.match(r"^(\D+?)[^a-zA-Z]", signal)
+            signal = match.group(1) if match else signal
+            ProxyClassMember("%s.%s" % (sender, signal), "connect", 0)(slot)
 
         connect = classmethod(connect)
 
