@@ -20,24 +20,31 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
+# Import future modules
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 # Import built-in modules
 import logging
 import os.path
 import re
 import sys
 
+# Import local modules
+from pyuiw.uic.exceptions import NoSuchWidgetError
+from pyuiw.uic.objcreator import QObjectCreator
+from pyuiw.uic.properties import Properties
+
 
 try:
     # Import built-in modules
     from xml.etree.cElementTree import SubElement
     from xml.etree.cElementTree import parse
 except ImportError:
-    from xml.etree.ElementTree import parse, SubElement
-
-# Import third-party modules
-from pyuiw.uic.exceptions import NoSuchWidgetError
-from pyuiw.uic.objcreator import QObjectCreator
-from pyuiw.uic.properties import Properties
+    # Import built-in modules
+    from xml.etree.ElementTree import SubElement
+    from xml.etree.ElementTree import parse
 
 
 logger = logging.getLogger(__name__)
@@ -749,7 +756,6 @@ class UIParser(object):
         self.stack.popWidget()
         self.addActions()
         self.setBuddies()
-        self.setDelayedProps()
 
     def addActions(self):
         for widget, action_name in self.actions:
@@ -838,13 +844,14 @@ class UIParser(object):
         for conn in iter(elem):
             QtCore.QObject.connect(
                 name2object(conn.findtext("sender")),
-                QtCore.SIGNAL(conn.findtext("signal")),
+                conn.findtext("signal"),
                 self.factory.getSlot(
                     name2object(conn.findtext("receiver")),
                     conn.findtext("slot").split("(")[0],
                 ),
             )
         QtCore.QMetaObject.connectSlotsByName(self.toplevelWidget)
+        self.setDelayedProps()
 
     def customWidgets(self, elem):
         def header2module(header):
